@@ -45,19 +45,17 @@ class AgentConfig(TypedModel, type=AgentType.BASE):
     send_filler_audio: Union[bool, FillerAudioConfig] = False
 
 
+class CutOffResponse(BaseModel):
+    messages: list[BaseMessage] = [BaseMessage(text="Sorry?")]
+
+
 class LLMAgentConfig(AgentConfig, type=AgentType.LLM):
     prompt_preamble: str
     expected_first_prompt: Optional[str] = None
     model_name: str = LLM_AGENT_DEFAULT_MODEL_NAME
     temperature: float = LLM_AGENT_DEFAULT_TEMPERATURE
     max_tokens: int = LLM_AGENT_DEFAULT_MAX_TOKENS
-
-
-class ChatGPTAlphaAgentConfig(AgentConfig, type=AgentType.CHAT_GPT_ALPHA):
-    prompt_preamble: str
-    expected_first_prompt: Optional[str] = None
-    temperature: float = LLM_AGENT_DEFAULT_TEMPERATURE
-    max_tokens: int = LLM_AGENT_DEFAULT_MAX_TOKENS
+    cut_off_response: Optional[CutOffResponse] = None
 
 
 class ChatGPTAgentConfig(AgentConfig, type=AgentType.CHAT_GPT):
@@ -66,6 +64,7 @@ class ChatGPTAgentConfig(AgentConfig, type=AgentType.CHAT_GPT):
     generate_responses: bool = False
     temperature: float = LLM_AGENT_DEFAULT_TEMPERATURE
     max_tokens: int = LLM_AGENT_DEFAULT_MAX_TOKENS
+    cut_off_response: Optional[CutOffResponse] = None
 
 
 class InformationRetrievalAgentConfig(
@@ -134,6 +133,7 @@ class WebSocketAgentMessageType(str, Enum):
     BASE = "websocket_agent_base"
     START = "websocket_agent_start"
     TEXT = "websocket_agent_text"
+    TEXT_END = "websocket_agent_text_end"
     READY = "websocket_agent_ready"
     STOP = "websocket_agent_stop"
 
@@ -171,3 +171,9 @@ class WebSocketAgentStopMessage(
     WebSocketAgentMessage, type=WebSocketAgentMessageType.STOP
 ):
     pass
+
+
+class WebSocketAgentTextEndMessage(
+    WebSocketAgentMessage, type=WebSocketAgentMessageType.TEXT_END
+):
+    pass
